/*
 * VIDNS - Virtual Internal DNS management system
 * Copyright (C) 2022 lemon.sh
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of  MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program.  If not, see <http://www.gnu.org/licenses/>.
 */

use serde::Deserialize;
use std::net::SocketAddr;

#[derive(Deserialize)]
pub struct Config {
    pub web: Web,
    pub nsd: Nsd,
    pub database: String,
    pub log_level: Option<String>,
    pub soa: Soa,
}

#[derive(Deserialize)]
pub struct Nsd {
    pub zonefiles_path: String,
    pub pattern_name: String,
    pub nsd_control_binary: Option<String>,
}

#[derive(Deserialize)]
pub struct Soa {
    pub ttl: i32,
    pub mname: String,
    pub rname: String,
    pub refresh: u32,
    pub retry: u32,
    pub expire: u32,
    pub minimum: u32,
}

#[derive(Deserialize)]
pub struct Web {
    pub listen: SocketAddr,
    pub admin_password: String,
    pub allowed_tlds: Option<Vec<String>>,
    pub cookie_secret: String,
}
