/*
 * VIDNS - Virtual Internal DNS management system
 * Copyright (C) 2022 lemon.sh
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of  MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program.  If not, see <http://www.gnu.org/licenses/>.
 */

use anyhow::anyhow;
use std::{
    path::PathBuf,
    process::{Command, Output},
};

pub struct NsdControl {
    path: PathBuf,
}

fn parse_output(output: Output) -> anyhow::Result<String> {
    let output_str = String::from_utf8(output.stdout)?;
    if output.status.success() {
        Ok(output_str)
    } else {
        Err(anyhow!(
            "nsd-control failed with code {}: {}",
            output.status,
            output_str
        ))
    }
}

impl NsdControl {
    pub fn new(path: PathBuf) -> Self {
        Self { path }
    }

    pub fn serverpid(&self) -> anyhow::Result<usize> {
        let output = Command::new(&self.path).arg("serverpid").output()?;
        Ok(parse_output(output)?.parse()?)
    }
}
